#!/usr/bin/env node
"use strict";

var path = _interopRequireWildcard(require("path"));

var _banner = _interopRequireDefault(require("./banner"));

var _prepareArguments = _interopRequireDefault(require("./utils/prepare-arguments"));

var validators = _interopRequireWildcard(require("./utils/validators"));

var _index = _interopRequireDefault(require("./index"));

var _ora = _interopRequireDefault(require("ora"));

var _commander = _interopRequireDefault(require("commander"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

// Print program banner
console.log('\x1B[2J\x1B[0f');
console.log(_banner.default); // Configure the program

_commander.default.name('webcapture').usage('[options] <targets...>').option('-d, --debug', 'Enable the debug mode to print useful logs').option('-c, --crop', 'Crop the screenshot as the viewport size').option('-o, --output-dir <path>', 'Where to render the output files').option('-t, --timeout <number>', 'Sets the default timeout').option('-s, --selector <name>', 'The capture element selector').option('-f, --format <name>', 'Use a different output format', validators.validateFormat, 'png').option('-v, --viewport <name...>', 'Comma separated list of viewports', validators.validateViewport).option('-V, --viewport-category <name>', 'Capture all devices included in viewport category').parse(process.argv); // Exit if no targets


if (_commander.default.args.length === 0) {
  console.error('  You must specify one or more targets! \n');
  process.exit();
} // Prepare the input arguments


_commander.default.args = (0, _prepareArguments.default)(_commander.default.args); // Create the UI spinner

const spinner = (0, _ora.default)({
  spinner: 'dots',
  text: 'Starting the capture process..'
}); // Create a new capturer with given options

const capturer = new _index.default({
  debug: _commander.default.debug,
  timeout: _commander.default.timeout,
  outputDir: _commander.default.outputDir
}); // When a entry capture starts

capturer.on('capture:start', data => {
  spinner.color = 'yellow';
  spinner.start(`Capturing ${data.url}`);
}); // When a entry capture produces a warning

capturer.on('capture:warn', data => {
  spinner.text = `WARN: ${data}`;
}); // When a entry capture ends

capturer.on('capture:end', data => {
  const outPath = path.relative(process.cwd(), data.path);
  const duration = parseFloat(data.duration).toFixed(4);
  spinner.succeed(`Captured to ${outPath} in ${duration}ms`);
}); // Start capture

spinner.start();
capturer.capture(_commander.default.args, {
  type: _commander.default.format,
  viewport: _commander.default.viewport,
  viewportCategory: _commander.default.viewportCategory,
  captureSelector: _commander.default.selector
}).catch(console.error).then(() => {
  spinner.stop();
  console.log();
  return capturer.close();
});