"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isValidViewportObject = isValidViewportObject;
exports.validateType = validateType;
exports.isValidBase64 = isValidBase64;
exports.isValidURL = isValidURL;
exports.isValidHTML = isValidHTML;
Object.defineProperty(exports, "isValidPath", {
  enumerable: true,
  get: function () {
    return _isValidPath.default;
  }
});

var _ = _interopRequireWildcard(require("lodash"));

var _isValidPath = _interopRequireDefault(require("is-valid-path"));

var _isHtml = _interopRequireDefault(require("is-html"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

// Output type validation
const notBase64 = /[^A-Z0-9+/=]/i;
const supportedTypes = ['pdf', 'png', 'jpeg', 'html', 'base64', 'buffer']; // Viewport validation

const viewportObject = _.conforms({
  width: _.isNumber,
  height: _.isNumber
});

function isValidViewportObject(v) {
  return viewportObject(v);
}

function validateType(v) {
  v = v.toLowerCase();

  if (supportedTypes.includes(v)) {
    return v;
  }

  throw new Error(`The output type ${v} is not supported, must be one of [${supportedTypes.join(',')}]`);
}

function isValidBase64(v) {
  const len = v.length;

  if (!len || len % 4 !== 0 || notBase64.test(v)) {
    return false;
  }

  const firstPaddingChar = v.indexOf('=');
  return firstPaddingChar === -1 || firstPaddingChar === len - 1 || firstPaddingChar === len - 2 && v[len - 1] === '=';
}

function isValidURL(v) {
  return /^(https?|file):\/\/|^data:/.test(v);
}

function isValidHTML(v) {
  return (0, _isHtml.default)(v);
}